@@ -1,6 +1,6 @@
 from typing import Callable, List, Tuple
 
-from palett import Preset
+from palett.structs import Preset
 from palett.presets import FRESH, PLANET
 from texting import COLF, ELLIP, RTSP
 from texting.enum.brackets import BRC, NONE
